from setuptools import setup

setup(name='thg_probability',
      version='1.4',
      description='Gaussian and Binomial distributions',
      packages=['thg_probability'],
      author="Thomas Hatting",
      author_email= 'mail@thomashatting.co',
      zip_safe=False)
